==> cydex_3.3.1-buildbeta1_installer_oem-arkhub.tar.gz: cydex_3.3.1-buildbeta1_installer_oem-arkhub/config/sql/init_cydex.sql <==
INSERT INTO `db_cydex`.`server_config` ( `version`, `compatibility_s`, `compatibility_e`, `max_available_traffic`,
`cydex_manager_code`, `max_upload_bps`, `max_download_bps`, `project_max_segs_num`, `project_min_seg_size`,
`project_max_seg_size`, `calcu_traffic_interval`, `package_expire`, `package_delete_expire`,
`overdraw_n`, `size_n`, `server_name`, `system_id`)
VALUES ('N/A', 1, 3, 10240,
'centre', 0, 0, 25, 52428800,
2147483648, 1, 0, 0,
0.0, 1.00, 'Arkhub', '');

INSERT INTO `db_cydex`.`zone` (`id`, `name`, `host`, `description`, `secret_key`) 
VALUES ('1', 'default', 'http://127.0.0.1:9007', 'default zone', '123456');

INSERT INTO `db_cydex`.`project_role_permission` (`id`, `code`, `role_id`, `is_allowed`, `description`)
VALUES 
('1', '001001', '0', '1',  'create package'), 
('2', '001002', '0', '1',  'delete/update other people packages'), 
('3', '001003', '0', '1',  'invite members'), 
('4', '001004', '0', '1',  'delete members'), 
('5', '001005', '0', '1',  'View project basic information'), 
('6', '001006', '0', '1',  'View project statistics'), 
('7', '001007', '0', '1',  'Set Settings for other users'), 
('8', '001008', '0', '1',  'delete project'), 
('9', '001009', '0', '1',  'Modify the basic information of the project'),
('10',  '001010', '0', '1', 'Check other people package information'), 
('11',  '001011', '0', '1', 'View the project log'), 
('12',  '001001', '1', '1', 'create package'), 
('13',  '001002', '1', '1', 'delete/update other people packages'), 
('14',  '001003', '1', '1', 'invite members'), 
('15',  '001004', '1', '1', 'delete members'), 
('16',  '001005', '1', '1', 'View project basic information'), 
('17',  '001006', '1', '1', 'View project statistics'), 
('18',  '001007', '1', '1', 'Set Settings for other users'), 
('19',  '001009', '1', '1', 'Modify the basic information of the project'), 
('20',  '001010', '1', '1', 'Check package information that is not related to you'), 
('21',  '001011', '1', '1', 'View project log'), 
('22',  '001001', '2', '1', 'create package'), 
('23',  '001005', '2', '1', 'View project basic information');

==> cydex_3.4.1-buildbeta1_installer_oem-arkhub.tar.gz: cydex_3.4.1-buildbeta1_installer_oem-arkhub/config/sql/init_cydex.sql <==
INSERT INTO `db_cydex`.`server_config` ( `version`, `compatibility_s`, `compatibility_e`, `max_available_traffic`,
`cydex_manager_code`, `max_upload_bps`, `max_download_bps`, `project_max_segs_num`, `project_min_seg_size`,
`project_max_seg_size`, `calcu_traffic_interval`, `package_expire`, `package_delete_expire`,
`overdraw_n`, `size_n`, `server_name`, `server_type`, `system_id`)
VALUES ('N/A', 1, 3, 10240,
'centre', 0, 0, 25, 52428800,
2147483648, 1, 0, 0,
0.0, 1.00, 'Arkhub', 'Arkhub', '');

INSERT INTO `db_cydex`.`zone` (`id`, `name`, `host`, `description`, `secret_key`) 
VALUES ('1', 'default', 'http://127.0.0.1:9007', 'default zone', '123456');

INSERT INTO `db_cydex`.`project_role_permission` (`id`, `code`, `role_id`, `is_allowed`, `description`)
VALUES 
('1', '001001', '0', '1',  'create package'), 
('2', '001002', '0', '1',  'delete/update other people packages'), 
('3', '001003', '0', '1',  'invite members'), 
('4', '001004', '0', '1',  'delete members'), 
('5', '001005', '0', '1',  'View project basic information'), 
('6', '001006', '0', '1',  'View project statistics'), 
('7', '001007', '0', '1',  'Set Settings for other users'), 
('8', '001008', '0', '1',  'delete project'), 
('9', '001009', '0', '1',  'Modify the basic information of the project'),
('10',  '001010', '0', '1', 'Check other people package information'), 
('11',  '001011', '0', '1', 'View the project log'), 
('12',  '001001', '1', '1', 'create package'), 
('13',  '001002', '1', '1', 'delete/update other people packages'), 
('14',  '001003', '1', '1', 'invite members'), 
('15',  '001004', '1', '1', 'delete members'), 
('16',  '001005', '1', '1', 'View project basic information'), 
('17',  '001006', '1', '1', 'View project statistics'), 
('18',  '001007', '1', '1', 'Set Settings for other users'), 
('19',  '001009', '1', '1', 'Modify the basic information of the project'), 
('20',  '001010', '1', '1', 'Check package information that is not related to you'), 
('21',  '001011', '1', '1', 'View project log'), 
('22',  '001001', '2', '1', 'create package'), 
('23',  '001005', '2', '1', 'View project basic information');
